==> data-hub-6.0.0-sources.jar: io/intino/datahub/model/Struct.java <==
package io.intino.datahub.model;

import io.intino.datahub.model.*;

public class Struct  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected java.util.List<io.intino.datahub.model.Struct.Attribute> attributeList = new java.util.ArrayList<>();
	protected io.intino.datahub.model.Struct.ExtensionOf _extensionOf;

	public Struct(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public java.util.List<io.intino.datahub.model.Struct.Attribute> attributeList() {
		return java.util.Collections.unmodifiableList(attributeList);
	}

	public io.intino.datahub.model.Struct.Attribute attribute(int index) {
		return attributeList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Struct.Attribute> attributeList(java.util.function.Predicate<io.intino.datahub.model.Struct.Attribute> predicate) {
		return attributeList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Struct.Attribute attribute(java.util.function.Predicate<io.intino.datahub.model.Struct.Attribute> predicate) {
		return attributeList().stream().filter(predicate).findFirst().orElse(null);
	}

	public io.intino.datahub.model.Struct.ExtensionOf asExtensionOf() {
		return a$(io.intino.datahub.model.Struct.ExtensionOf.class);
	}

	public io.intino.datahub.model.Struct.ExtensionOf asExtensionOf(io.intino.datahub.model.Struct struct) {
		io.intino.datahub.model.Struct.ExtensionOf newElement = core$().addAspect(io.intino.datahub.model.Struct.ExtensionOf.class);
		newElement.core$().set(newElement, "struct", java.util.Collections.singletonList(struct));
		return newElement;
	}

	public boolean isExtensionOf() {
		return core$().is(io.intino.datahub.model.Struct.ExtensionOf.class);
	}

	public void removeExtensionOf() {
		core$().removeAspect(io.intino.datahub.model.Struct.ExtensionOf.class);
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(attributeList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Struct$Attribute")) this.attributeList.add(node.as(io.intino.datahub.model.Struct.Attribute.class));
	}

	@Override
	protected void removeNode$(io.intino.magritte.framework.Node node) {
		super.removeNode$(node);
		if (node.is("Struct$Attribute")) this.attributeList.remove(node.as(io.intino.datahub.model.Struct.Attribute.class));
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.datahub.model.Struct.Attribute attribute() {
			io.intino.datahub.model.Struct.Attribute newElement = core$().graph().concept(io.intino.datahub.model.Struct.Attribute.class).createNode(this.name, core$()).as(io.intino.datahub.model.Struct.Attribute.class);

			return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void attribute(java.util.function.Predicate<io.intino.datahub.model.Struct.Attribute> filter) {
			new java.util.ArrayList<>(attributeList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}
	}

	public static class Attribute extends io.intino.datahub.model.EntityData implements io.intino.magritte.framework.tags.Terminal {

		public Attribute(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.datahub.model.NessGraph graph() {
			return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
		}
	}

	public static class ExtensionOf  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.datahub.model.Struct struct;
		protected io.intino.datahub.model.Struct _struct;

		public ExtensionOf(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.datahub.model.Struct struct() {
			return struct;
		}

		public ExtensionOf struct(io.intino.datahub.model.Struct value) {
			this.struct = value;
			return (ExtensionOf) this;
		}

		public java.util.List<io.intino.datahub.model.Struct.Attribute> attributeList() {
			return (java.util.List<io.intino.datahub.model.Struct.Attribute>) _struct.attributeList();
		}

		public io.intino.datahub.model.Struct.Attribute attributeList(int index) {
			return _struct.attributeList().get(index);
		}
		public io.intino.datahub.model.Struct asStruct() {
			return (io.intino.datahub.model.Struct) a$(io.intino.datahub.model.Struct.class);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("struct", this.struct != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.struct)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("struct")) this.struct = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.datahub.model.Struct.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("struct")) this.struct = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.datahub.model.Struct.class) : null;
		}

		@Override
		protected void sync$(io.intino.magritte.framework.Layer layer) {
			super.sync$(layer);
			if (layer instanceof io.intino.datahub.model.Struct) _struct = (io.intino.datahub.model.Struct) layer;

		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}

			public io.intino.datahub.model.Struct.Attribute attribute() {
				io.intino.datahub.model.Struct.Attribute newElement = core$().graph().concept(io.intino.datahub.model.Struct.Attribute.class).createNode(this.name, core$()).as(io.intino.datahub.model.Struct.Attribute.class);

				return newElement;
			}

		}

		public Clear clear() {
			return new Clear();
		}

		public class Clear  {
			public void attribute(java.util.function.Predicate<io.intino.datahub.model.Struct.Attribute> filter) {
				new java.util.ArrayList<>(attributeList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}
		}

		public io.intino.datahub.model.NessGraph graph() {
			return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
		}
	}


	public io.intino.datahub.model.NessGraph graph() {
		return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
	}
}

==> data-hub-6.3.2-sources.jar: io/intino/datahub/model/Struct.java <==
package io.intino.datahub.model;

import io.intino.datahub.model.*;

public class Struct  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
	protected java.util.List<io.intino.datahub.model.Struct.Attribute> attributeList = new java.util.ArrayList<>();
	protected java.util.List<io.intino.datahub.model.Struct.Method> methodList = new java.util.ArrayList<>();
	protected io.intino.datahub.model.Struct.ExtensionOf _extensionOf;

	public Struct(io.intino.magritte.framework.Node node) {
		super(node);
	}

	public java.util.List<io.intino.datahub.model.Struct.Attribute> attributeList() {
		return java.util.Collections.unmodifiableList(attributeList);
	}

	public io.intino.datahub.model.Struct.Attribute attribute(int index) {
		return attributeList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Struct.Attribute> attributeList(java.util.function.Predicate<io.intino.datahub.model.Struct.Attribute> predicate) {
		return attributeList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Struct.Attribute attribute(java.util.function.Predicate<io.intino.datahub.model.Struct.Attribute> predicate) {
		return attributeList().stream().filter(predicate).findFirst().orElse(null);
	}

	public java.util.List<io.intino.datahub.model.Struct.Method> methodList() {
		return java.util.Collections.unmodifiableList(methodList);
	}

	public io.intino.datahub.model.Struct.Method method(int index) {
		return methodList.get(index);
	}

	public java.util.List<io.intino.datahub.model.Struct.Method> methodList(java.util.function.Predicate<io.intino.datahub.model.Struct.Method> predicate) {
		return methodList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}

	public io.intino.datahub.model.Struct.Method method(java.util.function.Predicate<io.intino.datahub.model.Struct.Method> predicate) {
		return methodList().stream().filter(predicate).findFirst().orElse(null);
	}

	public io.intino.datahub.model.Struct.ExtensionOf asExtensionOf() {
		return a$(io.intino.datahub.model.Struct.ExtensionOf.class);
	}

	public io.intino.datahub.model.Struct.ExtensionOf asExtensionOf(io.intino.datahub.model.Struct struct) {
		io.intino.datahub.model.Struct.ExtensionOf newElement = core$().addAspect(io.intino.datahub.model.Struct.ExtensionOf.class);
		newElement.core$().set(newElement, "struct", java.util.Collections.singletonList(struct));
		return newElement;
	}

	public boolean isExtensionOf() {
		return core$().is(io.intino.datahub.model.Struct.ExtensionOf.class);
	}

	public void removeExtensionOf() {
		core$().removeAspect(io.intino.datahub.model.Struct.ExtensionOf.class);
	}

	protected java.util.List<io.intino.magritte.framework.Node> componentList$() {
		java.util.Set<io.intino.magritte.framework.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(attributeList).forEach(c -> components.add(c.core$()));
		new java.util.ArrayList<>(methodList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
		return map;
	}

	@Override
	protected void addNode$(io.intino.magritte.framework.Node node) {
		super.addNode$(node);
		if (node.is("Struct$Attribute")) this.attributeList.add(node.as(io.intino.datahub.model.Struct.Attribute.class));
		if (node.is("Struct$Method")) this.methodList.add(node.as(io.intino.datahub.model.Struct.Method.class));
	}

	@Override
	protected void removeNode$(io.intino.magritte.framework.Node node) {
		super.removeNode$(node);
		if (node.is("Struct$Attribute")) this.attributeList.remove(node.as(io.intino.datahub.model.Struct.Attribute.class));
		if (node.is("Struct$Method")) this.methodList.remove(node.as(io.intino.datahub.model.Struct.Method.class));
	}

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}

		public io.intino.datahub.model.Struct.Attribute attribute() {
			io.intino.datahub.model.Struct.Attribute newElement = core$().graph().concept(io.intino.datahub.model.Struct.Attribute.class).createNode(this.name, core$()).as(io.intino.datahub.model.Struct.Attribute.class);

			return newElement;
		}

		public io.intino.datahub.model.Struct.Method method() {
			io.intino.datahub.model.Struct.Method newElement = core$().graph().concept(io.intino.datahub.model.Struct.Method.class).createNode(this.name, core$()).as(io.intino.datahub.model.Struct.Method.class);

			return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void attribute(java.util.function.Predicate<io.intino.datahub.model.Struct.Attribute> filter) {
			new java.util.ArrayList<>(attributeList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}

		public void method(java.util.function.Predicate<io.intino.datahub.model.Struct.Method> filter) {
			new java.util.ArrayList<>(methodList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
		}
	}

	public static class Attribute extends io.intino.datahub.model.StructData implements io.intino.magritte.framework.tags.Terminal {

		public Attribute(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.datahub.model.NessGraph graph() {
			return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
		}
	}

	public static class Method extends io.intino.datahub.model.Expression implements io.intino.magritte.framework.tags.Terminal {

		public Method(io.intino.magritte.framework.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public io.intino.datahub.model.NessGraph graph() {
			return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
		}
	}

	public static class ExtensionOf  extends io.intino.magritte.framework.Layer implements io.intino.magritte.framework.tags.Terminal {
		protected io.intino.datahub.model.Struct struct;
		protected io.intino.datahub.model.Struct _struct;

		public ExtensionOf(io.intino.magritte.framework.Node node) {
			super(node);
		}

		public io.intino.datahub.model.Struct struct() {
			return struct;
		}

		public ExtensionOf struct(io.intino.datahub.model.Struct value) {
			this.struct = value;
			return (ExtensionOf) this;
		}

		public java.util.List<io.intino.datahub.model.Struct.Attribute> attributeList() {
			return (java.util.List<io.intino.datahub.model.Struct.Attribute>) _struct.attributeList();
		}

		public io.intino.datahub.model.Struct.Attribute attributeList(int index) {
			return _struct.attributeList().get(index);
		}

		public java.util.List<io.intino.datahub.model.Struct.Method> methodList() {
			return (java.util.List<io.intino.datahub.model.Struct.Method>) _struct.methodList();
		}

		public io.intino.datahub.model.Struct.Method methodList(int index) {
			return _struct.methodList().get(index);
		}
		public io.intino.datahub.model.Struct asStruct() {
			return (io.intino.datahub.model.Struct) a$(io.intino.datahub.model.Struct.class);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<java.lang.String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("struct", this.struct != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.struct)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("struct")) this.struct = io.intino.magritte.framework.loaders.NodeLoader.load(values, io.intino.datahub.model.Struct.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("struct")) this.struct = values.get(0)!= null ? core$().graph().load(((io.intino.magritte.framework.Layer) values.get(0)).core$().id()).as(io.intino.datahub.model.Struct.class) : null;
		}

		@Override
		protected void sync$(io.intino.magritte.framework.Layer layer) {
			super.sync$(layer);
			if (layer instanceof io.intino.datahub.model.Struct) _struct = (io.intino.datahub.model.Struct) layer;

		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}

			public io.intino.datahub.model.Struct.Attribute attribute() {
				io.intino.datahub.model.Struct.Attribute newElement = core$().graph().concept(io.intino.datahub.model.Struct.Attribute.class).createNode(this.name, core$()).as(io.intino.datahub.model.Struct.Attribute.class);

				return newElement;
			}

			public io.intino.datahub.model.Struct.Method method() {
				io.intino.datahub.model.Struct.Method newElement = core$().graph().concept(io.intino.datahub.model.Struct.Method.class).createNode(this.name, core$()).as(io.intino.datahub.model.Struct.Method.class);

				return newElement;
			}

		}

		public Clear clear() {
			return new Clear();
		}

		public class Clear  {
			public void attribute(java.util.function.Predicate<io.intino.datahub.model.Struct.Attribute> filter) {
				new java.util.ArrayList<>(attributeList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}

			public void method(java.util.function.Predicate<io.intino.datahub.model.Struct.Method> filter) {
				new java.util.ArrayList<>(methodList()).stream().filter(filter).forEach(io.intino.magritte.framework.Layer::delete$);
			}
		}

		public io.intino.datahub.model.NessGraph graph() {
			return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
		}
	}


	public io.intino.datahub.model.NessGraph graph() {
		return (io.intino.datahub.model.NessGraph) core$().graph().as(io.intino.datahub.model.NessGraph.class);
	}
}
